==> duiba-api-0.3.6-sources.jar: cn/com/duiba/api/bo/mq/MqDataParam.java <==
package cn.com.duiba.api.bo.mq;

import java.io.Serializable;
import java.util.Map;

/**
 * ClassName:MqDataParam<br/>
 *
 * @author gey
 * @version 1.0
 * @Description: Mq 处理 所需参数
 * @date 创建时间：2018/4/16  10:34
 * @since JDK 1.8
 **/
public class MqDataParam implements Serializable{

    private static final long serialVersionUID = 7266947718733738119L;
    /** 活动类型 活动工具 */
    @Deprecated //使用PrizeProcessTypeEnum
    public static final String ACTIVITY_TYPE_HD_TOOL = "hdtool";
    /** 活动类型 插件活动 */
    @Deprecated
    public static final String ACTIVITY_TYPE_PLUGIN = "plugin";
    /** 活动类型 集卡直接出奖 */
    @Deprecated
    public static final String ACTIVITY_TYPE_COLLECT_DIRECT = "collectDirect";

    /** 开奖回调失败消息回调类型 - 集卡开奖 */
    public static final String CALLBACK_BIZ_TYPE_COLLECT_CARD = "collectCard";

    private String factoryKey ;
    private Long appId ;
    private Long consumerId ;
    private Long opId;
    private Long duibaId;
    private Long standbyDuibaId; //降级用活动id
    private String partnerUserId;
    private String ip;
    private Boolean proxy;
    private Long subOrderId;//活动工具子订单id
    private String orderNum;//插件子订单id
    private String transfer;
    private String activityType;//活动类型 hdtool 活动工具， plugin 插件
    private Boolean isBusiness = false;
    private Long switchs;//位运算字段
    private String extendJson;//扩展字段1  json 格式
	private String gameExtendJson;//游戏扩展字段
    private String collectRuleId; //集卡规则id
    private String title; //活动名称 op 表中字段
    private String tag;//兑吧活动身上打的标签  发放福袋时使用
    private String os;//福袋发放使用
    private String soltId;//福袋发放使用
    private Integer opType;//福袋发放使用
    private String cookiesParams;
    //投放渠道,发放福袋专用
    private Integer channelType;
    private String json;//扩展字段
    private Boolean increaseJoinNum;//插件使用   是否记录 参与次数
    private String subType;// 插件使用  插件活动的类型
    private Boolean dubboCall = true;//活动工具  闯关游戏 使用

    private String userAgent;//cookie 字段
    private String deap;//cookie 字段
    private String tokenId;//cookie 字段
    private Long credits;
    //本次消耗积分
    private Long currentCredits;

    /** 集卡直接发奖用 start */

    /**兑吧商品ID*/
    private Long itemId;
    /**开发者商品ID*/
    private Long appItemId;
    /**奖项类型，同ItemDO.Type*/
    private String prizeType;
    /**奖项名称*/
    private String prizeName;

    /** 集卡直接发奖用 end */

    /**插件/活动工具-创建时间(毫秒数) 新旧集卡分流使用*/
    private Long activityCreateTime;

    /**
     * 预警类型
     */
    private Integer warningType;

    /**
     * 预警收件人
     */
    private String warningRecipient;

    //一下几个字段不是从mq 消息中获取
    private String chargeMode;
    private Integer relationType;
    private String developerBizId;//开发者业务流水
    //优惠券id  中优惠券时  赋值
    private Long couponId;
    private String facePrice;
    private Long mainOrderId;
    private String mainOrderNum;
    //程序异常是 赋值
    private String error4Admin;
    private String error4Developer;
    private String error4Consumer;
    private Integer exchangeStatus;//交易状态  1  待领取    2 领奖成功
    //回调topic
    private String callbackTopic;
    //回调业务类型
    private String callbackBizType;
    //回调消息额外参数 - 不扣积分
    private Map<String,String> extraParam;
    //回调消息额外参数 - 扣积分
    private String extraParamJson;
    
    /** 奖品定制key 主要为定制活动使用       废弃先该字段复制 都是 在定制代码中写死*/
    private String customerKey;
    /** 奖品定制key 主要为定制活动使用  都从活动配置上获取*/
    private String customerKeyNew;

    public Integer getExchangeStatus() {
        return exchangeStatus;
    }
    public void setExchangeStatus(Integer exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }
    public String getFactoryKey() {
        return factoryKey;
    }
    public void setFactoryKey(String factoryKey) {
        this.factoryKey = factoryKey;
    }
    public Long getAppId() {
        return appId;
    }
    public void setAppId(Long appId) {
        this.appId = appId;
    }
    public Long getConsumerId() {
        return consumerId;
    }
    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }
    public Long getOpId() {
        return opId;
    }
    public void setOpId(Long opId) {
        this.opId = opId;
    }
    public Long getDuibaId() {
        return duibaId;
    }
    public void setDuibaId(Long duibaId) {
        this.duibaId = duibaId;
    }

    public Long getStandbyDuibaId() {
        return standbyDuibaId;
    }

    public void setStandbyDuibaId(Long standbyDuibaId) {
        this.standbyDuibaId = standbyDuibaId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }
    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }
    public String getIp() {
        return ip;
    }
    public void setIp(String ip) {
        this.ip = ip;
    }
    public Boolean getProxy() {
        return proxy;
    }
    public void setProxy(Boolean proxy) {
        this.proxy = proxy;
    }
    public Long getSubOrderId() {
        return subOrderId;
    }
    public void setSubOrderId(Long subOrderId) {
        this.subOrderId = subOrderId;
    }
    public String getOrderNum() {
        return orderNum;
    }
    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }
    public String getTransfer() {
        return transfer;
    }
    public void setTransfer(String transfer) {
        this.transfer = transfer;
    }
    public String getActivityType() {
        return activityType;
    }
    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }
    public boolean isBusiness() {
        return isBusiness;
    }
    public void setBusiness(boolean isBusiness) {
        this.isBusiness = isBusiness;
    }
    public Long getSwitchs() {
        return switchs;
    }
    public void setSwitchs(Long switchs) {
        this.switchs = switchs;
    }
    public String getExtendJson() {
        return extendJson;
    }
    public void setExtendJson(String extendJson) {
        this.extendJson = extendJson;
    }
    public String getCollectRuleId() {
        return collectRuleId;
    }
    public void setCollectRuleId(String collectRuleId) {
        this.collectRuleId = collectRuleId;
    }
    public String getTitle() {
        return title;
    }
    public void setTitle(String title) {
        this.title = title;
    }
    public String getTag() {
        return tag;
    }
    public void setTag(String tag) {
        this.tag = tag;
    }
    public String getOs() {
        return os;
    }
    public void setOs(String os) {
        this.os = os;
    }
    public String getSoltId() {
        return soltId;
    }
    public void setSoltId(String soltId) {
        this.soltId = soltId;
    }
    public Integer getOpType() {
        return opType;
    }
    public void setOpType(Integer opType) {
        this.opType = opType;
    }
    public String getUserAgent() {
        return userAgent;
    }
    public void setUserAgent(String userAgent) {
        this.userAgent = userAgent;
    }
    public String getDeap() {
        return deap;
    }
    public void setDeap(String deap) {
        this.deap = deap;
    }
    public String getTokenId() {
        return tokenId;
    }
    public void setTokenId(String tokenId) {
        this.tokenId = tokenId;
    }
    public String getDeveloperBizId() {
        return developerBizId;
    }
    public void setDeveloperBizId(String developerBizId) {
        this.developerBizId = developerBizId;
    }
    public Long getCredits() {
        return credits;
    }
    public void setCredits(Long credits) {
        this.credits = credits;
    }
    public String getChargeMode() {
        return chargeMode;
    }
    public void setChargeMode(String chargeMode) {
        this.chargeMode = chargeMode;
    }
    public Integer getRelationType() {
        return relationType;
    }
    public void setRelationType(Integer relationType) {
        this.relationType = relationType;
    }
    public Long getCouponId() {
        return couponId;
    }
    public void setCouponId(Long couponId) {
        this.couponId = couponId;
    }
    public String getError4Admin() {
        return error4Admin;
    }
    public void setError4Admin(String error4Admin) {
        this.error4Admin = error4Admin;
    }
    public String getError4Developer() {
        return error4Developer;
    }
    public void setError4Developer(String error4Developer) {
        this.error4Developer = error4Developer;
    }
    public String getError4Consumer() {
        return error4Consumer;
    }
    public void setError4Consumer(String error4Consumer) {
        this.error4Consumer = error4Consumer;
    }
    public String getFacePrice() {
        return facePrice;
    }
    public void setFacePrice(String facePrice) {
        this.facePrice = facePrice;
    }
    public Long getMainOrderId() {
        return mainOrderId;
    }
    public void setMainOrderId(Long mainOrderId) {
        this.mainOrderId = mainOrderId;
    }
    public String getMainOrderNum() {
        return mainOrderNum;
    }
    public void setMainOrderNum(String mainOrderNum) {
        this.mainOrderNum = mainOrderNum;
    }

    public String getCookiesParams() {
        return cookiesParams;
    }

    public void setCookiesParams(String cookiesParams) {
        this.cookiesParams = cookiesParams;
    }
    public Integer getChannelType() {
        return channelType;
    }
    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public Boolean getIncreaseJoinNum() {
        return increaseJoinNum;
    }

    public void setIncreaseJoinNum(Boolean increaseJoinNum) {
        this.increaseJoinNum = increaseJoinNum;
    }

    public String getJson() {
        return json;
    }
    public void setJson(String json) {
        this.json = json;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public Boolean getDubboCall() {
        return dubboCall;
    }

    public void setDubboCall(Boolean dubboCall) {
        this.dubboCall = dubboCall;
    }

    public Long getCurrentCredits() {
        return currentCredits;
    }

    public void setCurrentCredits(Long currentCredits) {
        this.currentCredits = currentCredits;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public Long getActivityCreateTime() {
        return activityCreateTime;
    }

    public void setActivityCreateTime(Long activityCreateTime) {
        this.activityCreateTime = activityCreateTime;
    }
	public String getGameExtendJson() {
		return gameExtendJson;
	}
	public void setGameExtendJson(String gameExtendJson) {
		this.gameExtendJson = gameExtendJson;
	}
	public String getCustomerKey() {
		return customerKey;
	}
	public void setCustomerKey(String customerKey) {
		this.customerKey = customerKey;
	}

    public String getCallbackTopic() {
        return callbackTopic;
    }

    public void setCallbackTopic(String callbackTopic) {
        this.callbackTopic = callbackTopic;
    }

    public String getCallbackBizType() {
        return callbackBizType;
    }

    public void setCallbackBizType(String callbackBizType) {
        this.callbackBizType = callbackBizType;
    }

    public Map<String, String> getExtraParam() {
        return extraParam;
    }

    public void setExtraParam(Map<String, String> extraParam) {
        this.extraParam = extraParam;
    }
	public String getCustomerKeyNew() {
		return customerKeyNew;
	}
	public void setCustomerKeyNew(String customerKeyNew) {
		this.customerKeyNew = customerKeyNew;
	}

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getExtraParamJson() {
        return extraParamJson;
    }

    public void setExtraParamJson(String extraParamJson) {
        this.extraParamJson = extraParamJson;
    }

    public Integer getWarningType() {
        return warningType;
    }

    public void setWarningType(Integer warningType) {
        this.warningType = warningType;
    }

    public String getWarningRecipient() {
        return warningRecipient;
    }

    public void setWarningRecipient(String warningRecipient) {
        this.warningRecipient = warningRecipient;
    }
}

==> duiba-api-0.7.2-sources.jar: cn/com/duiba/api/bo/mq/MqDataParam.java <==
package cn.com.duiba.api.bo.mq;

import java.io.Serializable;
import java.util.Map;

/**
 * ClassName:MqDataParam<br/>
 *
 * @author gey
 * @version 1.0
 * @Description: Mq 处理 所需参数
 * @date 创建时间：2018/4/16  10:34
 * @since JDK 1.8
 **/
public class MqDataParam implements Serializable{

    private static final long serialVersionUID = 7266947718733738119L;
    /** 活动类型 活动工具 */
    @Deprecated //使用PrizeProcessTypeEnum
    public static final String ACTIVITY_TYPE_HD_TOOL = "hdtool";
    /** 活动类型 插件活动 */
    @Deprecated
    public static final String ACTIVITY_TYPE_PLUGIN = "plugin";
    /** 活动类型 集卡直接出奖 */
    @Deprecated
    public static final String ACTIVITY_TYPE_COLLECT_DIRECT = "collectDirect";

    /** 开奖回调失败消息回调类型 - 集卡开奖 */
    public static final String CALLBACK_BIZ_TYPE_COLLECT_CARD = "collectCard";

    private String factoryKey ;
    private Long appId ;
    private Long consumerId ;
    private Long opId;
    private Long duibaId;
    private Long standbyDuibaId; //降级用活动id
    private String partnerUserId;
    private String ip;
    private Boolean proxy;
    private Long subOrderId;//活动工具子订单id
    private String orderNum;//插件子订单id
    private String transfer;
    private String activityType;//活动类型 hdtool 活动工具， plugin 插件
    /**
     * 统一的活动类型： 见 ActivityUniformityTypeEnum
     */
    private Integer activityUniformityType;
    private Boolean isBusiness = false;
    private Long switchs;//位运算字段
    private String extendJson;//扩展字段1  json 格式
	private String gameExtendJson;//游戏扩展字段
    private String collectRuleId; //集卡规则id
    private String title; //活动名称 op 表中字段
    private String tag;//兑吧活动身上打的标签  发放福袋时使用
    private String os;//福袋发放使用
    private String soltId;//福袋发放使用
    private Integer opType;//福袋发放使用
    private String cookiesParams;
    //投放渠道,发放福袋专用
    private Integer channelType;
    private String json;//扩展字段
    private Boolean increaseJoinNum;//插件使用   是否记录 参与次数
    private String subType;// 插件使用  插件活动的类型
    private Boolean dubboCall = true;//活动工具  闯关游戏 使用

    private String userAgent;//cookie 字段
    private String deap;//cookie 字段
    private String tokenId;//cookie 字段
    private Long credits;
    //本次消耗积分
    private Long currentCredits;

    /** 集卡直接发奖用 start */

    /**兑吧商品ID*/
    private Long itemId;
    /**开发者商品ID*/
    private Long appItemId;
    /**奖项类型，同ItemDO.Type*/
    private String prizeType;
    /**奖项名称*/
    private String prizeName;

    /** 集卡直接发奖用 end */

    /**插件/活动工具-创建时间(毫秒数) 新旧集卡分流使用*/
    private Long activityCreateTime;

    /**
     * 预警类型
     */
    private Integer warningType;

    /**
     * 预警收件人
     */
    private String warningRecipient;

    //一下几个字段不是从mq 消息中获取
    private String chargeMode;
    private Integer relationType;
    private String developerBizId;//开发者业务流水
    //优惠券id  中优惠券时  赋值
    private Long couponId;
    private String facePrice;
    private Long mainOrderId;
    private String mainOrderNum;
    //程序异常是 赋值
    private String error4Admin;
    private String error4Developer;
    private String error4Consumer;
    private Integer exchangeStatus;//交易状态  1  待领取    2 领奖成功
    //回调topic
    private String callbackTopic;
    //回调业务类型
    private String callbackBizType;
    //回调消息额外参数 - 不扣积分
    private Map<String,String> extraParam;
    //回调消息额外参数 - 扣积分
    private String extraParamJson;
    
    /** 奖品定制key 主要为定制活动使用       废弃先该字段复制 都是 在定制代码中写死*/
    private String customerKey;
    /** 奖品定制key 主要为定制活动使用  都从活动配置上获取*/
    private String customerKeyNew;
    /**
     * 插件关联的活动入库id or 关联的签到入库
     */
    private Long pluginRelationOptId;
    /**
     * 插件关联的活动入d or 关联的签到活动id
     */
    private Long pluginRelationActId;
    /**
     *插件关联的统一活动类型 ActivityUniformityTypeEnum
     */
    private Integer pluginRelationActType;

    public Integer getExchangeStatus() {
        return exchangeStatus;
    }
    public void setExchangeStatus(Integer exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }
    public String getFactoryKey() {
        return factoryKey;
    }
    public void setFactoryKey(String factoryKey) {
        this.factoryKey = factoryKey;
    }
    public Long getAppId() {
        return appId;
    }
    public void setAppId(Long appId) {
        this.appId = appId;
    }
    public Long getConsumerId() {
        return consumerId;
    }
    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }
    public Long getOpId() {
        return opId;
    }
    public void setOpId(Long opId) {
        this.opId = opId;
    }
    public Long getDuibaId() {
        return duibaId;
    }
    public void setDuibaId(Long duibaId) {
        this.duibaId = duibaId;
    }

    public Long getStandbyDuibaId() {
        return standbyDuibaId;
    }

    public void setStandbyDuibaId(Long standbyDuibaId) {
        this.standbyDuibaId = standbyDuibaId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }
    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }
    public String getIp() {
        return ip;
    }
    public void setIp(String ip) {
        this.ip = ip;
    }
    public Boolean getProxy() {
        return proxy;
    }
    public void setProxy(Boolean proxy) {
        this.proxy = proxy;
    }
    public Long getSubOrderId() {
        return subOrderId;
    }
    public void setSubOrderId(Long subOrderId) {
        this.subOrderId = subOrderId;
    }
    public String getOrderNum() {
        return orderNum;
    }
    public void setOrderNum(String orderNum) {
        this.orderNum = orderNum;
    }
    public String getTransfer() {
        return transfer;
    }
    public void setTransfer(String transfer) {
        this.transfer = transfer;
    }
    public String getActivityType() {
        return activityType;
    }
    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }
    public boolean isBusiness() {
        return isBusiness;
    }
    public void setBusiness(boolean isBusiness) {
        this.isBusiness = isBusiness;
    }
    public Long getSwitchs() {
        return switchs;
    }
    public void setSwitchs(Long switchs) {
        this.switchs = switchs;
    }
    public String getExtendJson() {
        return extendJson;
    }
    public void setExtendJson(String extendJson) {
        this.extendJson = extendJson;
    }
    public String getCollectRuleId() {
        return collectRuleId;
    }
    public void setCollectRuleId(String collectRuleId) {
        this.collectRuleId = collectRuleId;
    }
    public String getTitle() {
        return title;
    }
    public void setTitle(String title) {
        this.title = title;
    }
    public String getTag() {
        return tag;
    }
    public void setTag(String tag) {
        this.tag = tag;
    }
    public String getOs() {
        return os;
    }
    public void setOs(String os) {
        this.os = os;
    }
    public String getSoltId() {
        return soltId;
    }
    public void setSoltId(String soltId) {
        this.soltId = soltId;
    }
    public Integer getOpType() {
        return opType;
    }
    public void setOpType(Integer opType) {
        this.opType = opType;
    }
    public String getUserAgent() {
        return userAgent;
    }
    public void setUserAgent(String userAgent) {
        this.userAgent = userAgent;
    }
    public String getDeap() {
        return deap;
    }
    public void setDeap(String deap) {
        this.deap = deap;
    }
    public String getTokenId() {
        return tokenId;
    }
    public void setTokenId(String tokenId) {
        this.tokenId = tokenId;
    }
    public String getDeveloperBizId() {
        return developerBizId;
    }
    public void setDeveloperBizId(String developerBizId) {
        this.developerBizId = developerBizId;
    }
    public Long getCredits() {
        return credits;
    }
    public void setCredits(Long credits) {
        this.credits = credits;
    }
    public String getChargeMode() {
        return chargeMode;
    }
    public void setChargeMode(String chargeMode) {
        this.chargeMode = chargeMode;
    }
    public Integer getRelationType() {
        return relationType;
    }
    public void setRelationType(Integer relationType) {
        this.relationType = relationType;
    }
    public Long getCouponId() {
        return couponId;
    }
    public void setCouponId(Long couponId) {
        this.couponId = couponId;
    }
    public String getError4Admin() {
        return error4Admin;
    }
    public void setError4Admin(String error4Admin) {
        this.error4Admin = error4Admin;
    }
    public String getError4Developer() {
        return error4Developer;
    }
    public void setError4Developer(String error4Developer) {
        this.error4Developer = error4Developer;
    }
    public String getError4Consumer() {
        return error4Consumer;
    }
    public void setError4Consumer(String error4Consumer) {
        this.error4Consumer = error4Consumer;
    }
    public String getFacePrice() {
        return facePrice;
    }
    public void setFacePrice(String facePrice) {
        this.facePrice = facePrice;
    }
    public Long getMainOrderId() {
        return mainOrderId;
    }
    public void setMainOrderId(Long mainOrderId) {
        this.mainOrderId = mainOrderId;
    }
    public String getMainOrderNum() {
        return mainOrderNum;
    }
    public void setMainOrderNum(String mainOrderNum) {
        this.mainOrderNum = mainOrderNum;
    }

    public String getCookiesParams() {
        return cookiesParams;
    }

    public void setCookiesParams(String cookiesParams) {
        this.cookiesParams = cookiesParams;
    }
    public Integer getChannelType() {
        return channelType;
    }
    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public Boolean getIncreaseJoinNum() {
        return increaseJoinNum;
    }

    public void setIncreaseJoinNum(Boolean increaseJoinNum) {
        this.increaseJoinNum = increaseJoinNum;
    }

    public String getJson() {
        return json;
    }
    public void setJson(String json) {
        this.json = json;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public Boolean getDubboCall() {
        return dubboCall;
    }

    public void setDubboCall(Boolean dubboCall) {
        this.dubboCall = dubboCall;
    }

    public Long getCurrentCredits() {
        return currentCredits;
    }

    public void setCurrentCredits(Long currentCredits) {
        this.currentCredits = currentCredits;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public Long getActivityCreateTime() {
        return activityCreateTime;
    }

    public void setActivityCreateTime(Long activityCreateTime) {
        this.activityCreateTime = activityCreateTime;
    }
	public String getGameExtendJson() {
		return gameExtendJson;
	}
	public void setGameExtendJson(String gameExtendJson) {
		this.gameExtendJson = gameExtendJson;
	}
	public String getCustomerKey() {
		return customerKey;
	}
	public void setCustomerKey(String customerKey) {
		this.customerKey = customerKey;
	}

    public String getCallbackTopic() {
        return callbackTopic;
    }

    public void setCallbackTopic(String callbackTopic) {
        this.callbackTopic = callbackTopic;
    }

    public String getCallbackBizType() {
        return callbackBizType;
    }

    public void setCallbackBizType(String callbackBizType) {
        this.callbackBizType = callbackBizType;
    }

    public Map<String, String> getExtraParam() {
        return extraParam;
    }

    public void setExtraParam(Map<String, String> extraParam) {
        this.extraParam = extraParam;
    }
	public String getCustomerKeyNew() {
		return customerKeyNew;
	}
	public void setCustomerKeyNew(String customerKeyNew) {
		this.customerKeyNew = customerKeyNew;
	}

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getExtraParamJson() {
        return extraParamJson;
    }

    public void setExtraParamJson(String extraParamJson) {
        this.extraParamJson = extraParamJson;
    }

    public Integer getWarningType() {
        return warningType;
    }

    public void setWarningType(Integer warningType) {
        this.warningType = warningType;
    }

    public String getWarningRecipient() {
        return warningRecipient;
    }

    public void setWarningRecipient(String warningRecipient) {
        this.warningRecipient = warningRecipient;
    }

    public Long getPluginRelationOptId() {
        return pluginRelationOptId;
    }

    public void setPluginRelationOptId(Long pluginRelationOptId) {
        this.pluginRelationOptId = pluginRelationOptId;
    }

    public Integer getPluginRelationActType() {
        return pluginRelationActType;
    }

    public Long getPluginRelationActId() {
        return pluginRelationActId;
    }

    public void setPluginRelationActId(Long pluginRelationActId) {
        this.pluginRelationActId = pluginRelationActId;
    }

    public void setPluginRelationActType(Integer pluginRelationActType) {
        this.pluginRelationActType = pluginRelationActType;
    }

    public Integer getActivityUniformityType() {
        return activityUniformityType;
    }

    public void setActivityUniformityType(Integer activityUniformityType) {
        this.activityUniformityType = activityUniformityType;
    }
}
